==> dicee-0.0.2-py3-none-any.whl: tests/test_read_few_only.py <==
from dicee.executer import Execute, get_default_arguments
import sys
import pytest


class TestReadFewOnly:
    @pytest.mark.filterwarnings('ignore::UserWarning')
    def test_qmult_kvsall(self):
        args = get_default_arguments([])
        args.model = 'QMult'
        args.num_epochs = 1
        args.scoring_technique = 'KvsAll'
        args.path_dataset_folder = 'KGs/UMLS'
        args.num_epochs = 10
        args.batch_size = 1024
        args.lr = 0.01
        args.embedding_dim = 32
        args.input_dropout_rate = 0.0
        args.hidden_dropout_rate = 0.0
        args.feature_map_dropout_rate = 0.0
        args.eval_model = 'train'
        args.sample_triples_ratio = None
        args.read_only_few = 10
        args.trainer = 'torchCPUTrainer'
        report = Execute(args).start()
        # as we add negative triples
        assert report['num_train_triples'] == int(args.read_only_few * 2)

    @pytest.mark.filterwarnings('ignore::UserWarning')
    def test_qmult_1vsall(self):
        args = get_default_arguments([])
        args.model = 'QMult'
        args.num_epochs = 1
        args.scoring_technique = '1vsAll'
        args.path_dataset_folder = 'KGs/UMLS'
        args.num_epochs = 10
        args.batch_size = 1024
        args.lr = 0.01
        args.embedding_dim = 32
        args.input_dropout_rate = 0.0
        args.hidden_dropout_rate = 0.0
        args.feature_map_dropout_rate = 0.0
        args.eval_model = 'train'
        args.read_only_few = 10
        args.sample_triples_ratio = None
        args.trainer = 'torchCPUTrainer'
        report = Execute(args).start()
        # as we add negative triples
        assert report['num_train_triples'] == int(args.read_only_few * 2)

    @pytest.mark.filterwarnings('ignore::UserWarning')
    def test_qmult_neg_sampling(self):
        args = get_default_arguments([])
        args.model = 'QMult'
        args.num_epochs = 1
        args.scoring_technique = 'NegSample'
        args.path_dataset_folder = 'KGs/UMLS'
        args.num_epochs = 10
        args.batch_size = 1024
        args.lr = 0.01
        args.embedding_dim = 32
        args.input_dropout_rate = 0.0
        args.hidden_dropout_rate = 0.0
        args.feature_map_dropout_rate = 0.0
        args.eval_model = 'train'
        args.read_only_few = 10
        args.sample_triples_ratio = None
        args.neg_ratio = 1
        args.trainer = 'torchCPUTrainer'
        report = Execute(args).start()
        # as we add negative triples
        assert report['num_train_triples'] == args.read_only_few

==> dicee-0.0.4-py3-none-any.whl: tests/test_read_few_only.py <==
from dicee.executer import Execute
import sys
import pytest
from dicee.config import Args

class TestReadFewOnly:
    @pytest.mark.filterwarnings('ignore::UserWarning')
    def test_qmult_kvsall(self):
        args = Args()
        args.model = 'QMult'
        args.num_epochs = 1
        args.scoring_technique = 'KvsAll'
        args.path_dataset_folder = 'KGs/UMLS'
        args.num_epochs = 10
        args.batch_size = 1024
        args.lr = 0.01
        args.embedding_dim = 32
        args.input_dropout_rate = 0.0
        args.hidden_dropout_rate = 0.0
        args.feature_map_dropout_rate = 0.0
        args.eval_model = 'train'
        args.sample_triples_ratio = None
        args.read_only_few = 10
        args.trainer = 'torchCPUTrainer'
        report = Execute(args).start()
        # as we add negative triples
        assert report['num_train_triples'] == int(args.read_only_few * 2)

    @pytest.mark.filterwarnings('ignore::UserWarning')
    def test_qmult_1vsall(self):
        args = Args()  # get_default_arguments([])
        args.model = 'QMult'
        args.num_epochs = 1
        args.scoring_technique = '1vsAll'
        args.path_dataset_folder = 'KGs/UMLS'
        args.num_epochs = 10
        args.batch_size = 1024
        args.lr = 0.01
        args.embedding_dim = 32
        args.input_dropout_rate = 0.0
        args.hidden_dropout_rate = 0.0
        args.feature_map_dropout_rate = 0.0
        args.eval_model = 'train'
        args.read_only_few = 10
        args.sample_triples_ratio = None
        args.trainer = 'torchCPUTrainer'
        report = Execute(args).start()
        # as we add negative triples
        assert report['num_train_triples'] == int(args.read_only_few * 2)

    @pytest.mark.filterwarnings('ignore::UserWarning')
    def test_qmult_neg_sampling(self):
        args = Args()  # get_default_arguments([])
        args.model = 'QMult'
        args.num_epochs = 1
        args.scoring_technique = 'NegSample'
        args.path_dataset_folder = 'KGs/UMLS'
        args.num_epochs = 10
        args.batch_size = 1024
        args.lr = 0.01
        args.embedding_dim = 32
        args.input_dropout_rate = 0.0
        args.hidden_dropout_rate = 0.0
        args.feature_map_dropout_rate = 0.0
        args.eval_model = 'train'
        args.read_only_few = 10
        args.sample_triples_ratio = None
        args.neg_ratio = 1
        args.trainer = 'torchCPUTrainer'
        report = Execute(args).start()
        # as we add negative triples
        assert report['num_train_triples'] == args.read_only_few
